# OpenCue TSC Meeting Notes 6 July 2022

Secretary: Brian Cipriano

Agenda/Notes:

* New business
    * API changes to fail on incorrect parameters
        * https://github.com/AcademySoftwareFoundation/OpenCue/pull/1165/files
        * no issues, good to merge when code/tests are ready
    * Make frames and layers readonly after job finishes
        * https://github.com/AcademySoftwareFoundation/OpenCue/pull/1164
        * https://github.com/AcademySoftwareFoundation/OpenCue/pull/1163
        * solution seems ok, but should be a cuebot config flag for now
    * Siggraph/Open Source Days
        * Few folks attending Siggraph likely. Brian will be OOO and unable to attend.
        * Will hybrid in-person/virtual sessions be supported?
        * How to design the session?
        * Brian to do some research and start email thread.
    * Integration tests
        * Integration test script being developed at SPI.
        * We will want to look at turning it into a github action.
        * This will help speed up the release process a lot. Most of the time spent making a release is QAing it.
        * SPI to update soon.
* Ongoing work
    * CueGUI memory leak
        * https://github.com/AcademySoftwareFoundation/OpenCue/issues/1025
        * What we know: bug in job monitor tree creates unnecessary refreshing. Probably present in all tree plugins,
          but most apparent when monitoring 100s/1000s of jobs.
        * SPI: researching and testing their fix.
    * RQD change, adding child proc info into log, storing in database
        * For understanding memory usage of complex jobs.
        * Linux-only.
        * Testing ongoing, feedback has been positive so far.
        * Change was deployed to production, found some issues, fixed.
        * Work is done. Has it been merged to github yet?
    * Avoiding complex merges from upstream.
        * Problem: users will maintain their own OpenCue forks with many preferred customizations. When it comes time to
          merge in changes from upstream, a complex merge is needed. This is time consuming and results in long gaps
          between upstream merges.
        * How do others solve this?
        * Suggestion: let's identify the various areas needing customization, and discuss how we can generalize a
          solution by creating options/plugins/hooks so customization can live outside the main codebase.
        * Most spots identified, PRs have been sent
        * Upstream merge almost complete, will resume that soon.
    * OS-dependent log root
        * Issue: https://github.com/AcademySoftwareFoundation/OpenCue/issues/1096
        * PR: https://github.com/AcademySoftwareFoundation/OpenCue/pull/1102
        * PR merged.
        * New PR to fix log paths on the CueGUI side: https://github.com/AcademySoftwareFoundation/OpenCue/pull/1138
        * All PRs merged. Done now.
    * Nimby in new thread: https://github.com/AcademySoftwareFoundation/OpenCue/pull/1063
        * Not reproducible? We need input from SPI.
        * Reproduced now. PR coming with several rqd/nimby fixes.
        * pynput will become the default for detecting system activity.
    * Sentry logging in CueGUI: https://github.com/AcademySoftwareFoundation/OpenCue/pull/1127
        * Change looks ok, looking for more detail.
        * Let's follow up on that PR again, review, figure out if we need to clone to new PR.
* 2022 Goals
    * New user UX
        * Publish PyPI packages
            * Design doc: https://docs.google.com/document/d/1pWjMNGzGmBvuHoBzXewQEzdwTKtrY6VOtaPi7ALwWg0/
            * Proposal for config file
              standardization: https://docs.google.com/document/d/1pWjMNGzGmBvuHoBzXewQEzdwTKtrY6VOtaPi7ALwWg0/edit#heading=h.v85uo9klwqft
            * Config cleanup for pycue, pyoutline, cuesubmit done.
            * CueGUI in progress.
            * RQD still todo.
        * Fix cuebot:latest tag for sandbox setup
            * Proposal: publish Docker images for every new patch version (i.e. every new commit to master)
            * Proposal accepted.
            * No progress implementing this yet.
            * Related: for PyPI design we may want to also publish packages for every new patch version.
    * Docs refresh
        * Tech writing help
            * Discussing with John Mertic at LF and OCIO reps who are also interested.
        * User guide refresh
            * Split into "install from latest release" and "install from master"
            * Needed to assist transition to publish Docker images on all commits
            * No progress.
        * API reference
            * We have the ability to generate HTML from any commit, but we need a new CI pipeline to build and publish
              this on opencue.io for new releases.
            * Proposal: for now, highlight existing docs for building reference locally
            * Proposal accepted.
            * Brian: cleaned up local build process, sent email with doc
              link: https://www.opencue.io/contributing/opencue/build-docs/
        * pyoutline examples
            * https://github.com/AcademySoftwareFoundation/OpenCue/issues/177
            * No progress yet.
        * User guide for CueGUI
            * No progress.
        * Configuration guides for Python/Cuebot/RQD
            * In progress, will be done as part of PyPI work.
    * Improve scheduler logic
        * Diego has volunteered to own this.
        * Email reply from Matt, looped in others.
        * Other PRs with improvements — see ongoing work above.
        * Prototype in progress.
        * High-level prototype details using Redis: https://github.com/AcademySoftwareFoundation/OpenCue/issues/1001
    * Expanded Cloud functionality
        * Finalize GSoC plugin
            * Test Azure support
            * Add AWS support
        * Design expanded functionality e.g. autoscaling for work in the queue.
        * Last update from Greg: started to test / clean up azure support. Looking good so far.
        * Terraform scripts?
            * Let's look at the Azure version of this
        * Generic k8s setup and cuebot pool size suggestions
        * Existing Azure work on this: https://github.com/Azure/Avere/tree/main/src/terraform/examples/vfxt/opencue
        * Issue for discussion: https://github.com/AcademySoftwareFoundation/OpenCue/issues/1097
        * Use Kubernetes for rqd? Kubernetes adds some overhead. A very small amount but some people care.
        * A Helm chart could be a good option. Easy to use and get started.
        * Let's review the Github issue, leave notes. Short, rough draft of design doc for auto-scaling would be good
          for further discussion.
    * User permissions
        * Need a github issue for discussion.
        * Added initial
          thoughts: https://github.com/AcademySoftwareFoundation/OpenCue/issues/218#issuecomment-1016904933
        * Need more research into integration with Active Directory.
        * Permissions model: proposal to be written up.
    * Expand DCC plugins
        * High priority: Blender, Houdini
        * Important for wider user adoption.
        * Worth writing to the user group to see what folks have already.
        * No further progress.
